Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( ErrNotAuthorized = errors.New("not authorized") ErrNotFound = errors.New("not found") )
Functions ¶
func AsmSecretPath ¶
Types ¶
type CredentialManager ¶
type CredentialManager interface {
// Name should provide a loggable and error-returnable identifying
// name for the credential manager.
Name() string
// Password should retrieve the password for a given identity.
// If the identity is not found, an error should be returned.
// IMPORTANT: While the identity given for the password should
// be trusted, we should not assume the identity should have
// access to the database they're requesting it for. It's the
// responsibility of the Password call to ensure that the given
// IAM ARN _should_ have access to the given DB.
Password(reqLogger *log.Entry, identity DBKey) (string, error)
}
func RetrieveConfigured ¶
RetrieveConfigured checks the environment for configured cred providers, and selects the first working configuration.
Click to show internal directories.
Click to hide internal directories.